// ====================================================================
// This file is part of FlexibleSUSY.
//
// FlexibleSUSY is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published
// by the Free Software Foundation, either version 3 of the License,
// or (at your option) any later version.
//
// FlexibleSUSY is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with FlexibleSUSY.  If not, see
// <http://www.gnu.org/licenses/>.
// ====================================================================

// File generated at Sun 18 Oct 2015 11:31:35

#include "TMSSM_two_scale_soft_parameters.hpp"
#include "wrappers.hpp"

namespace flexiblesusy {

#define INPUT(parameter) input.parameter
#define TRACE_STRUCT soft_traces

/**
 * Calculates the one-loop beta function of BMu.
 *
 * @return one-loop beta function
 */
double TMSSM_soft_parameters::calc_beta_BMu_one_loop(const Soft_traces& soft_traces) const
{
   const double traceYdAdjYd = TRACE_STRUCT.traceYdAdjYd;
   const double traceYeAdjYe = TRACE_STRUCT.traceYeAdjYe;
   const double traceYuAdjYu = TRACE_STRUCT.traceYuAdjYu;
   const double traceAdjYdTYd = TRACE_STRUCT.traceAdjYdTYd;
   const double traceAdjYeTYe = TRACE_STRUCT.traceAdjYeTYe;
   const double traceAdjYuTYu = TRACE_STRUCT.traceAdjYuTYu;


   double beta_BMu;

   beta_BMu = Re(oneOver16PiSqr*(6*traceAdjYdTYd*Mu + 2*traceAdjYeTYe*Mu
      + 6*traceAdjYuTYu*Mu + 1.2*MassB*Mu*Sqr(g1) + BMu*(3*traceYdAdjYd +
      traceYeAdjYe + 3*traceYuAdjYu + 3*AbsSqr(Lambdax) - 0.6*Sqr(g1) - 3*Sqr(
      g2)) + 6*MassWB*Mu*Sqr(g2) + 6*Conj(Lambdax)*Mu*TLambdax));


   return beta_BMu;
}

/**
 * Calculates the two-loop beta function of BMu.
 *
 * @return two-loop beta function
 */
double TMSSM_soft_parameters::calc_beta_BMu_two_loop(const Soft_traces& soft_traces) const
{
   const double traceYdAdjYd = TRACE_STRUCT.traceYdAdjYd;
   const double traceYeAdjYe = TRACE_STRUCT.traceYeAdjYe;
   const double traceYuAdjYu = TRACE_STRUCT.traceYuAdjYu;
   const double traceYdAdjYdYdAdjYd = TRACE_STRUCT.traceYdAdjYdYdAdjYd;
   const double traceYdAdjYuYuAdjYd = TRACE_STRUCT.traceYdAdjYuYuAdjYd;
   const double traceYeAdjYeYeAdjYe = TRACE_STRUCT.traceYeAdjYeYeAdjYe;
   const double traceYuAdjYuYuAdjYu = TRACE_STRUCT.traceYuAdjYuYuAdjYu;
   const double traceAdjYdTYd = TRACE_STRUCT.traceAdjYdTYd;
   const double traceAdjYeTYe = TRACE_STRUCT.traceAdjYeTYe;
   const double traceAdjYuTYu = TRACE_STRUCT.traceAdjYuTYu;
   const double traceYdAdjYdTYdAdjYd = TRACE_STRUCT.traceYdAdjYdTYdAdjYd;
   const double traceYdAdjYuTYuAdjYd = TRACE_STRUCT.traceYdAdjYuTYuAdjYd;
   const double traceYeAdjYeTYeAdjYe = TRACE_STRUCT.traceYeAdjYeTYeAdjYe;
   const double traceYuAdjYdTYdAdjYu = TRACE_STRUCT.traceYuAdjYdTYdAdjYu;
   const double traceYuAdjYuTYuAdjYu = TRACE_STRUCT.traceYuAdjYuTYuAdjYu;


   double beta_BMu;

   beta_BMu = Re(0.02*twoLoop*(BMu*(207*Power(g1,4) + 675*Power(g2,4) -
      450*traceYdAdjYdYdAdjYd - 300*traceYdAdjYuYuAdjYd - 150*
      traceYeAdjYeYeAdjYe - 450*traceYuAdjYuYuAdjYu + 60*traceYeAdjYe*Sqr(g1) +
      40*traceYuAdjYu*Sqr(g1) + 90*Sqr(g1)*Sqr(g2) + 75*AbsSqr(Lambdax)*(-3*
      traceYdAdjYd - traceYeAdjYe - 3*traceYuAdjYu + 8*Sqr(g2)) - 20*
      traceYdAdjYd*(Sqr(g1) - 40*Sqr(g3)) + 800*traceYuAdjYu*Sqr(g3) - 375*Sqr(
      Conj(Lambdax))*Sqr(Lambdax)) - 2*Mu*(414*Power(g1,4)*MassB + 1350*Power(
      g2,4)*MassWB + 900*traceYdAdjYdTYdAdjYd + 300*traceYdAdjYuTYuAdjYd + 300*
      traceYeAdjYeTYeAdjYe + 300*traceYuAdjYdTYdAdjYu + 900*
      traceYuAdjYuTYuAdjYu + 20*traceAdjYdTYd*Sqr(g1) - 60*traceAdjYeTYe*Sqr(g1
      ) - 40*traceAdjYuTYu*Sqr(g1) + 60*MassB*traceYeAdjYe*Sqr(g1) + 40*MassB*
      traceYuAdjYu*Sqr(g1) + 90*MassB*Sqr(g1)*Sqr(g2) + 90*MassWB*Sqr(g1)*Sqr(
      g2) - 800*traceAdjYdTYd*Sqr(g3) - 800*traceAdjYuTYu*Sqr(g3) + 800*MassG*
      traceYuAdjYu*Sqr(g3) - 20*traceYdAdjYd*(MassB*Sqr(g1) - 40*MassG*Sqr(g3))
      + 750*Lambdax*Sqr(Conj(Lambdax))*TLambdax + 75*Conj(Lambdax)*(Lambdax*(3
      *traceAdjYdTYd + traceAdjYeTYe + 3*traceAdjYuTYu + 8*MassWB*Sqr(g2)) + (3
      *traceYdAdjYd + traceYeAdjYe + 3*traceYuAdjYu - 8*Sqr(g2))*TLambdax))));


   return beta_BMu;
}

/**
 * Calculates the three-loop beta function of BMu.
 *
 * @return three-loop beta function
 */
double TMSSM_soft_parameters::calc_beta_BMu_three_loop(const Soft_traces& soft_traces) const
{
   DEFINE_PROJECTOR(3,3,3,3)



   double beta_BMu;

   beta_BMu = 0;


   return beta_BMu;
}

} // namespace flexiblesusy
